CameraMacOSArguments class

Constructors

CameraMacOSArguments({int? textureId, required Size size, List<CameraMacOSDevice>? devices})
Create a CameraMacOSArguments.

Properties

devices → List<CameraMacOSDevice>?
Chosen device
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
Size of the texture.
final
textureId → int?
The texture id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited