CameraMacOSDevice class

Constructors

CameraMacOSDevice({required String deviceId, String? manufacturer, CameraMacOSDeviceType deviceType = CameraMacOSDeviceType.unknown, String? localizedName})
CameraMacOSDevice.fromMap(Map<String, dynamic> map)
factory

Properties

deviceId ↔ String
getter/setter pair
deviceType ↔ CameraMacOSDeviceType
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localizedName ↔ String?
getter/setter pair
manufacturer ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited