MethodChannelCameraMacOS class

An implementation of CameraMacosPlatform that uses method channels.

Inheritance

Constructors

MethodChannelCameraMacOS()

Properties

events ↔ StreamSubscription?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDestroyed ↔ bool
getter/setter pair
isRecording ↔ bool
getter/setter pair
isStreamingImageData → bool
no setter
methodCallHandlerSet ↔ bool
getter/setter pair
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
registeredCallbacks ↔ Map<String, Function?>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → Future<bool?>
Destroy the camera instance
override
initialize({String? deviceId, String? audioDeviceId, required CameraMacOSMode cameraMacOSMode, PictureFormat pictureFormat = PictureFormat.tiff, VideoFormat videoFormat = VideoFormat.mp4, PictureResolution resolution = PictureResolution.max, bool enableAudio = true, AudioFormat audioFormat = AudioFormat.kAudioFormatAppleLossless, AudioQuality audioQuality = AudioQuality.max, FlashMode flashMode = FlashMode.off, CameraOrientation orientation = CameraOrientation.orientation0deg, bool isVideoMirrored = true}) → Future<CameraMacOSArguments?>
Call this method to initialize camera. If you implement the widget in your widget tree, this method is useless.
override
listDevices({CameraMacOSDeviceType? deviceType}) → Future<List<CameraMacOSDevice>>
Call this method to discover all camera devices.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFlashMode(FlashMode mode) → Future<void>
override
setFocusPoint(Offset point) → Future<void>
override
setOrientation(CameraOrientation orientation) → Future<void>
override
setVideoMirrored(bool isVideoMirrored) → Future<void>
override
setZoomLevel(double zoom) → Future<void>
override
startImageStream(void onAvailable(CameraImageData? image), {void onError(dynamic)?}) → Future<void>
override
startVideoRecording({double? maxVideoDuration, bool? enableAudio, String? url, dynamic onVideoRecordingFinished(CameraMacOSFile?, CameraMacOSException?)?}) → Future<bool>
Call this method to start a video recording.
override
stopImageStream() → Future<void>
override
stopVideoRecording() → Future<CameraMacOSFile?>
Call this method to stop video recording and collect the video data.
override
takePicture({PictureFormat format = PictureFormat.tiff, PictureResolution resolution = PictureResolution.max}) → Future<CameraMacOSFile?>
Call this method to take a picture.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

eventChannel → const EventChannel