CameraMacOSPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CameraMacOSPlatform
Implementers

Constructors

CameraMacOSPlatform()
Constructs a CameraMacOSPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → Future<bool?>
initialize({String? deviceId, String? audioDeviceId, bool enableAudio = true, PictureFormat pictureFormat = PictureFormat.tiff, VideoFormat videoFormat = VideoFormat.mp4, PictureResolution resolution = PictureResolution.max, AudioFormat audioFormat = AudioFormat.kAudioFormatAppleLossless, AudioQuality audioQuality = AudioQuality.max, FlashMode flashMode = FlashMode.off, CameraOrientation orientation = CameraOrientation.orientation0deg, bool isVideoMirrored = true, required CameraMacOSMode cameraMacOSMode}) → Future<CameraMacOSArguments?>
listDevices({CameraMacOSDeviceType? deviceType}) → Future<List<CameraMacOSDevice>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFlashMode(FlashMode mode) → Future<void>
setFocusPoint(Offset point) → Future<void>
setOrientation(CameraOrientation orientation) → Future<void>
setVideoMirrored(bool isVideoMirrored) → Future<void>
setZoomLevel(double zoom) → Future<void>
startImageStream(void onAvailable(CameraImageData?), {void onError(dynamic)?}) → Future<void>
startVideoRecording({double? maxVideoDuration, String? url, bool? enableAudio, dynamic onVideoRecordingFinished(CameraMacOSFile?, CameraMacOSException?)?}) → Future<bool>
stopImageStream() → Future<void>
stopVideoRecording() → Future<CameraMacOSFile?>
takePicture() → Future<CameraMacOSFile?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ CameraMacOSPlatform
The default instance of CameraMacOSPlatform to use.
getter/setter pair