CameraMacOSView class

Inheritance

Constructors

CameraMacOSView({Key? key, String? deviceId, String? audioDeviceId, bool enableAudio = true, BoxFit fit = BoxFit.contain, required CameraMacOSMode cameraMode, required dynamic onCameraInizialized(CameraMacOSController), Widget onCameraLoading(Object?)?, Widget onCameraDestroyed()?, bool usePlatformView = false, PictureResolution resolution = PictureResolution.max, AudioQuality audioQuality = AudioQuality.max, PictureFormat pictureFormat = PictureFormat.tiff, VideoFormat videoFormat = VideoFormat.mp4, AudioFormat audioFormat = AudioFormat.kAudioFormatAppleLossless, FlashMode flashMode = FlashMode.off, CameraOrientation orientation = CameraOrientation.orientation0deg, bool isVideoMirrored = true})
const

Properties

audioDeviceId → String?
Audio DeviceId of the audio streaming device
final
audioFormat → AudioFormat
Format of the audion the video
final
audioQuality → AudioQuality
Quality of the output audio
final
cameraMode → CameraMacOSMode
Choose between audio or video mode
final
deviceId → String?
DeviceId of the video streaming device
final
enableAudio → bool
Enable audio while recording video. Defaults to 'true'. You can always override this setting when calling the 'startRecording' method.
final
fit → BoxFit
Handles how the widget should fit the screen.
final
flashMode → FlashMode
Flash/torch mode of the device
final
hashCode → int
The hash code for this object.
no setterinherited
isVideoMirrored → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCameraDestroyed → Widget Function()?
Callback that gets called when the "destroy" method has returned.
final
onCameraInizialized → dynamic Function(CameraMacOSController)
Callback that gets called when the "initialize" method has returned a value.
final
onCameraLoading → Widget Function(Object?)?
Callback that gets called while the "initialize" method hasn't returned a value yet.
final
orientation → CameraOrientation
The Orientation of the camera
final
pictureFormat → PictureFormat
Format of the output photo
final
resolution → PictureResolution
Resolution of the output video/image
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usePlatformView → bool
NOT WORKING It won't work until Flutter will officially support macOS Platform Views.
final
videoFormat → VideoFormat
Format of the output video
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → CameraMacOSViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited