NSKitPlatformViewController class

Inheritance

Constructors

NSKitPlatformViewController({required int paramsViewId})

Properties

awaitingCreation → bool
True if create has not been successfully called the platform view.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
paramsViewId ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewId → int
The viewId associated with this controller.
no setteroverride

Methods

clearFocus() → Future<void>
Clears the view's focus on the platform side.
override
create({Size? size, Offset? position}) → Future<void>
Creates the platform view with the initial size.
inherited
dispatchPointerEvent(PointerEvent event) → Future<void>
Dispatches the event to the platform view.
override
dispose() → Future<void>
Disposes the platform view.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited